@@ -40,6 +40,8 @@ def cmd(add_cmd, is_args=False):
             pattern = "^/" + add_cmd + "(\S+)"
         elif is_args=="unpin":
             pattern = "^/" + add_cmd + "($| (.*))"
+        elif is_args=="blacklist":
+            pattern = "^/" + add_cmd + "((.|\n)*)"
         else:
             pattern = "^/" + add_cmd + "$"
         utilsbot.add_event_handler(
